package com.example.criminalintent;

import java.util.ArrayList;

import android.app.Activity;
import android.app.ListFragment;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.CheckBox;
import android.widget.ListView;
import android.widget.TextView;

public class CrimeListFragment extends ListFragment
{
	public static final String KEY_POS = "position";
	
	private class CrimeAdapter extends ArrayAdapter<Crime>
	{
		public CrimeAdapter(ArrayList<Crime> crimes)
		{
			super(getActivity(), 0, crimes);
		}
		
		public View getView(int position, View convertView, ViewGroup parent)
		{
			if (convertView == null)
			{
				convertView = getActivity().getLayoutInflater().inflate(R.layout.crime_view, null);
			}
			Crime crime = crimes.get(position);
			
			TextView title = (TextView)convertView.findViewById(R.id.crimeTitleField);
			title.setText(crime.getTitle());
			TextView date = (TextView)convertView.findViewById(R.id.crimeDateField);
			date.setText(crime.getDate().toString());
			CheckBox solved = (CheckBox)convertView.findViewById(R.id.solvedCheckBox);
			solved.setChecked(crime.isSolved());
			return convertView;
		}
	}
	
	public interface OnCrimeSelectedListener
	{
		public void onCrimeSelected(int pos);
	}
	
	private ArrayList<Crime> crimes;
	private OnCrimeSelectedListener listener;
	
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		getActivity().setTitle("Crime List");
		
		crimes = CrimeLab.get(getActivity()).getCrimes();
		
		CrimeAdapter adapter = new CrimeAdapter(crimes);
		setListAdapter(adapter);
	}
	
	@Override
	public void onListItemClick(ListView l, View v, int position, long id)
	{
		listener.onCrimeSelected(position);
	}
	
	@Override
	public void onResume()
	{
		super.onResume();
		((CrimeAdapter)getListAdapter()).notifyDataSetChanged();
	}
	
	@Override
	public void onAttach(Activity activity)
	{
		super.onAttach(activity);
		try
		{
			listener = (OnCrimeSelectedListener)activity;
		}
		catch(ClassCastException ex)
		{
			Log.e("Crime", "Hosting class must implement OnCrimeSelectedListener", ex);
			throw new ClassCastException(activity.toString() + " must implement OnCrimeSelectedListener.");
		}
	}
	
	@Override
	public void onPause()
	{
		super.onPause();
		CrimeLab.get(getActivity()).save();
		
	}
}
